@@ -174,7 +174,7 @@ fn impl_model(ast: &syn::ItemStruct, attr: TokenStream, field_attributes: Fields
                 instance.images.push(image_id);
                 instance.modified = Utc::now();
 
-                cosmos_utils::upsert(#collection, [&#partition], &#prim, Some(&etag)).await?;
+                cosmos_utils::upsert(#collection, [&#partition], &instance, Some(&etag)).await?;
 
                 // TODO: Delete old image, if any.
                 Ok(warp::reply::json(&crate::util::DataResponse {
